@@ -158,7 +158,7 @@ static int read_auth_pass(struct plain_ctx_st *pctx)
 
 	fp = fopen(pctx->config->passwd, "r");
 	if (fp == NULL) {
-		syslog(LOG_AUTH,
+		syslog(LOG_NOTICE,
 		       "error in plain authentication; cannot open: %s",
 		       pctx->config->passwd);
 		return -1;
@@ -232,7 +232,7 @@ static int plain_auth_init(void **ctx, void *pool, void *vctx, const common_auth
 	int ret;
 
 	if (info->username == NULL || info->username[0] == 0) {
-		syslog(LOG_AUTH,
+		syslog(LOG_NOTICE,
 		       "plain-auth: no username present");
 		return ERR_AUTH_FAIL;
 	}
@@ -283,7 +283,7 @@ static int plain_auth_group(void *ctx, const char *suggested, char *groupname, i
 		}
 
 		if (found == 0) {
-			syslog(LOG_AUTH,
+			syslog(LOG_NOTICE,
 			       "user '%s' requested group '%s' but is not a member",
 			       pctx->username, suggested);
 			return -1;
@@ -322,7 +322,7 @@ static int plain_auth_pass(void *ctx, const char *pass, unsigned pass_len)
 			pctx->pass_msg = pass_msg_failed;
 			return ERR_AUTH_CONTINUE;
 		} else {
-			syslog(LOG_AUTH,
+			syslog(LOG_NOTICE,
 			       "plain-auth: error authenticating user '%s'",
 			       pctx->username);
 			return ERR_AUTH_FAIL;
@@ -330,7 +330,7 @@ static int plain_auth_pass(void *ctx, const char *pass, unsigned pass_len)
 	}
 
 	if (pctx->cpass[0] == 0 && pctx->config->otp_file == NULL) {
-		syslog(LOG_AUTH,
+		syslog(LOG_NOTICE,
 		       "plain-auth: user '%s' has empty password and no OTP file configured",
 		       pctx->username);
 		return ERR_AUTH_FAIL;
@@ -351,7 +351,7 @@ static int plain_auth_pass(void *ctx, const char *pass, unsigned pass_len)
 		ret = oath_authenticate_usersfile(pctx->config->otp_file, pctx->username,
 			pass, HOTP_WINDOW, NULL, &last);
 		if (ret != OATH_OK) {
-			syslog(LOG_AUTH,
+			syslog(LOG_NOTICE,
 			       "plain-auth: OTP auth failed for '%s': %s",
 			       pctx->username, oath_strerror(ret));
 			return ERR_AUTH_FAIL;
@@ -416,7 +416,7 @@ static void plain_group_list(void *pool, void *additional, char ***groupname, un
 	pool = talloc_init("plain");
 	fp = fopen(config->passwd, "r");
 	if (fp == NULL) {
-		syslog(LOG_AUTH,
+		syslog(LOG_NOTICE,
 		       "error in plain authentication; cannot open: %s",
 		       (char*)config->passwd);
 		return;
@@ -458,7 +458,7 @@ static void plain_group_list(void *pool, void *additional, char ***groupname, un
 
 					if (htable_get(&hash, hval, str_cmp, tgroup[i]) == NULL) {
 						if (strlen(tgroup[i]) > 1)
-							htable_add(&hash, hval, tgroup[i]);
+							(void)htable_add(&hash, hval, tgroup[i]);
 					}
 				}
 			}
