@@ -112,7 +112,7 @@ void set_self_oom_score_adj(main_server_st * s)
 	}
 
  cleanup:
-	if (fd) {
+	if (fd >= 0) {
 		close(fd);
 	}
 #endif
@@ -181,4 +181,5 @@ void drop_privileges(main_server_st * s)
 		mslog(s, NULL, LOG_ERR, "cannot enforce NPROC limit: %s\n",
 		      strerror(e));
 	}
-}
\ No newline at end of file
+}
+
