@@ -331,6 +331,8 @@ struct cfg_st {
 	char *xml_config_hash;
 #endif
 
+	unsigned client_bypass_protocol;
+
 	/* additional configuration files */
 	char *per_group_dir;
 	char *per_user_dir;
@@ -387,6 +389,7 @@ struct perm_cfg_st {
 	unsigned foreground;
 	unsigned no_chdir;
 	unsigned debug;
+	unsigned pr_dumpable;
 
 	char *ca;
 	char *dh_params_file;
