@@ -42,10 +42,6 @@ extern const ASN1_ARRAY_TYPE kkdcp_asn1_tab[];
 ASN1_TYPE _kkdcp_pkix1_asn = ASN1_TYPE_EMPTY;
 #endif
 
-// Name of environment variable used to pass worker_startup_msg 
-// between ocserv-main and ocserv-worker.
-#define OCSERV_ENV_WORKER_STARTUP_MSG "OCSERV_WORKER_STARTUP_MSG"
-
 extern struct snapshot_t *config_snapshot;
 
 int syslog_open = 0;
@@ -124,11 +120,6 @@ int main(int argc, char **argv)
 
 	restore_secmod_socket_file_name(ws->secmod_addr.sun_path);
 
-	// Close stdout and stderr early to avoid spurious logs
-	/* we don't need them */
-	close(STDIN_FILENO);
-	close(STDOUT_FILENO);
-
 	str = getenv("OCSERV_ALLOW_BROKEN_CLIENTS");
 	if (str && str[0] == '1' && str[1] == 0)
 		allow_broken_clients = 1;
